Changelog
=========

Version 1.0.4
-------------

* Add timestamp on execution


Version 1.0.3
-------------

* Improve quota-high debug


Version 1.0.2
-------------

* Fix parameter --quota-limit


Version 1.0.0
-------------

* Add processor quota-high
* Improve docs


Version 0.0.8
-------------

* Fix check_org_on_whitelist function


Version 0.0.7
-------------

* Ignore private ip addresses
* Add external script execution when an anomaly is found


Version 0.0.6
-------------

* Fix email report


Version 0.0.5
-------------

* Add option to send report by Mattermost


Version 0.0.4
-------------

* Add Sphinx documentation
* Add tests to sdist


Version 0.0.3
-------------

* Initial release